// Skip Barber Suspension
//////////////////////////////////////////////////////////////////////////
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of  another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the conventional definition of a hinge (eliminates 5 DOF).
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
// NOTE: the mass and inertia for the main vehicle "body" are not used because it is derived from the HDV file
// by subtracting out all the wheels, etc.  For all other bodies (wheels, spindles), they are important!
[BODY]
name=body mass=(0) inertia=(0,0,0)
pos=(0,0,0) ori=(0,0,0)

// Front spindles
[BODY]
name=fl_spindle mass=(9.7) inertia=(0.0275,0.0260,0.0245) // Unsprung masses that do not exhibit any pitch rotation with significant relation to the wheel rotation rate
pos=( 0.605,0,-1.35) ori=(0,0,0)

[BODY]
name=fr_spindle mass=(9.7) inertia=(0.0275,0.0260,0.0245)
pos=(-0.605,0,-1.35) ori=(0,0,0)

// Front wheels
[BODY]
name=fl_wheel mass=(14.9) inertia=(0.300,0.200,0.200) // Any unsprung bodies that rotate significantly in proportion to the wheel rotation rate, except for the tyre 'ring' (i.e. generally rim+disc/bell+bearing+nuts)
pos=( 0.676,0,-1.35) ori=(0,0,0)

[BODY]
name=fr_wheel mass=(14.9) inertia=(0.300,0.200,0.200)
pos=(-0.676,0,-1.35) ori=(0,0,0)

// Rear spindles
[BODY]
name=rl_spindle mass=(9.5) inertia=(0.0275,0.0260,0.0245)
pos=( 0.56,0,1.11) ori=(0,0,0)

[BODY]
name=rr_spindle mass=(9.5) inertia=(0.0275,0.0260,0.0245)
pos=(-0.56,0,1.11) ori=(0,0,0)

// Rear wheels (includes half of driveshaft)
[BODY]
name=rl_wheel mass=(14.1) inertia=(0.340,0.250,0.250)
pos=( 0.658,0,1.11) ori=(0,0,0)

[BODY]
name=rr_wheel mass=(14.1) inertia=(0.340,0.250,0.250)
pos=(-0.658,0,1.11) ori=(0,0,0)

// Fuel in tank is not rigidly attached - it is attached with springs and dampers to simulate movement.  Properties are defined in the HDV file.
[BODY]
name=fuel_tank mass=(0.5) inertia=(0.3,0.3,0.3) // Defines the minimum mass of remaining fuel in tank
pos=(0,0,0) ori=(0,0,0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle physics.
// Position is from the eyepoint defined in the VEH file, while other properties are defined in the head physics file.
[BODY]
name=driver_head mass=(6.6) inertia=(0.047,0.036,0.039)
pos=(0,0,0) ori=(0,0,0)

//////////////////////////////////////////////////////////////////////////
// Constraints
//////////////////////////////////////////////////////////////////////////

// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=( 0.68,0,0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(-0.68,0,0)


// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=( 0.352, 0.087945,-1.41) neg=( 0.5817, 0.127,-1.336)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=( 0.352, 0.087945,-1.100) neg=( 0.5817, 0.127,-1.336)

[BAR] // forward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=( 0.262,-0.1317625,-1.44) neg=( 0.622,-0.10175,-1.3556)

[BAR] // rearward lower arm
posbody=body negbody=fl_spindle pos=( 0.262,-0.1222375,-1.10) neg=( 0.622,-0.10175,-1.3556)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=( 0.311,-0.0348,-1.46) neg=( 0.611, 0.00,-1.46)


// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.352, 0.087945,-1.41) neg=(-0.5817, 0.127,-1.336)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.352, 0.087945,-1.100) neg=(-0.5817, 0.127,-1.336)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.262,-0.1317625,-1.44) neg=(-0.622,-0.10175,-1.3556)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.262,-0.1222375,-1.10) neg=(-0.622,-0.10175,-1.3556)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.311,-0.0348,-1.46) neg=(-0.611, 0.00,-1.46)


// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.338, 0.0394335,0.388) neg=(0.543,0.1706,1.1)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.338, 0.1100455,1.11) neg=(0.543,0.1706,1.1)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.203,-0.1891665,0.443) neg=(0.56,-0.1706,1.06)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.203,-0.1891665,1.07) neg=(0.56,-0.1706,1.06)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.203,-0.1891665,1.07) neg=(0.579,-0.1706,1.19)


// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.338, 0.0394335,0.388) neg=(-0.543,0.1706,1.1)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.338, 0.1100455,1.11) neg=(-0.543,0.1706,1.1)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.203,-0.1891665,0.443) neg=(-0.56,-0.1706,1.06)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.203,-0.1891665,1.07) neg=(-0.56,-0.1706,1.06)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.203,-0.1891665,1.07) neg=(-0.579,-0.1706,1.19)

// Rear spindle and wheel connections
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=( 0.66,0,0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(-0.66,0,0)
